//                                               -*- C++ -*-
/**
 *  @file  t_LinearLeastSquares_std.cxx
 *  @brief The test file of class LinearLeastSquares for standard methods
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: conty $
 *  @date:   $LastChangedDate: 2007-12-02 23:19:20 +0100 (dim 02 déc 2007) $
 *  Id:      $Id: t_LinearLeastSquares_std.cxx 693 2007-12-02 22:19:20Z conty $
 */
#include <iostream>
#include <sstream>
#include <exception>
#include "OT.hxx"
#include "OTtestcode.hxx"
#include <cmath>
#include "NumericalMathFunction.hxx"
#include "NumericalSample.hxx"
#include "NumericalPoint.hxx"
#include "LinearLeastSquares.hxx"

using namespace OT;
using namespace OT::Test;
using namespace OT::Base::Common;
using namespace OT::Base::Type;
using namespace OT::Base::Func;
using namespace OT::Base::Stat;
using namespace OT::Uncertainty::Algorithm;

int main(int argc, char *argv[])
{
  TESTPREAMBLE;

  try {
    NumericalMathFunction myFunc("TestResponseSurface");
    NumericalSample data(9, myFunc.getInputNumericalPointDimension());
    NumericalPoint point(myFunc.getInputNumericalPointDimension());
    point[0] = 0.5;
    point[1] = 0.5;
    data[0] = point;
    point[0] = -0.5;
    point[1] = -0.5;
    data[1] = point;
    point[0] = -0.5;
    point[1] = 0.5;
    data[2] = point;
    point[0] = 0.5;
    point[1] = -0.5;
    data[3] = point;
    point[0] = 0.5;
    point[1] = 0.5;
    data[4] = point;
    point[0] = -0.25;
    point[1] = -0.25;
    data[5] = point;
    point[0] = -0.25;
    point[1] = 0.25;
    data[6] = point;
    point[0] = 0.25;
    point[1] = -0.25;
    data[7] = point;
    point[0] = 0.25;
    point[1] = 0.25;
    data[8] = point;
    {
      LinearLeastSquares myLeastSquares(data, myFunc);
      myLeastSquares.run();
      NumericalMathFunction responseSurface(myLeastSquares.getResponseSurface());
      std::cout << "myLeastSquares=" << myLeastSquares << std::endl;
      std::cout << "responseSurface=" << responseSurface << std::endl;
      NumericalPoint in(myFunc.getInputNumericalPointDimension(),0.1);
      std::cout << "myFunc(" << in << ")=" << myFunc(in) << std::endl;
      std::cout << "responseSurface(" << in << ")=" << responseSurface(in) << std::endl;
    }
    {
      NumericalSample dataOut(myFunc(data));
      LinearLeastSquares myLeastSquares(data, dataOut);
      myLeastSquares.run();
      NumericalMathFunction responseSurface(myLeastSquares.getResponseSurface());
      std::cout << "myLeastSquares=" << myLeastSquares << std::endl;
      std::cout << "responseSurface=" << responseSurface << std::endl;
      NumericalPoint in(myFunc.getInputNumericalPointDimension(),0.1);
      std::cout << "myFunc(" << in << ")=" << myFunc(in) << std::endl;
      std::cout << "responseSurface(" << in << ")=" << responseSurface(in) << std::endl;
    }
  }
  catch (TestFailed & ex) {
    std::cerr << ex << std::endl;
    return ExitCode::Error;
  }


  return ExitCode::Success;
}
